@@ -162,6 +162,7 @@ fbetagpdcon <- function(x, phiu = TRUE, useq = NULL, fixedu = FALSE, pvector = N
 
   check.quant(x)
   n = length(x)
+  np = 4 # maximum number of parameters
 
   if (any(x > 1)) warning("values greater than one are assumed part of GPD")
 
@@ -174,8 +175,8 @@ fbetagpdcon <- function(x, phiu = TRUE, useq = NULL, fixedu = FALSE, pvector = N
   # Check if profile likelihood or fixed threshold is being used
   # and determine initial values for parameters in each case
   if (is.null(useq)) { # not profile or fixed
-    profu = FALSE
-    check.nparam(pvector, nparam = 4, allownull = TRUE)
+
+    check.nparam(pvector, nparam = np, allownull = TRUE)
     
     if (is.null(pvector)) {
       bmean = mean(x[x <= 1])
@@ -188,9 +189,8 @@ fbetagpdcon <- function(x, phiu = TRUE, useq = NULL, fixedu = FALSE, pvector = N
     }
     
   } else { # profile or fixed
-    profu = TRUE
     
-    check.nparam(pvector, nparam = 3, allownull = TRUE)
+    check.nparam(pvector, nparam = np - 1, allownull = TRUE)
 
     # profile likelihood for threshold or scalar given
     if (length(useq) != 1) {
@@ -209,7 +209,7 @@ fbetagpdcon <- function(x, phiu = TRUE, useq = NULL, fixedu = FALSE, pvector = N
       u = useq
     }
 
-    if (fixedu) { # threshold fixed (4 parameters)
+    if (fixedu) { # threshold fixed
       if (is.null(pvector)) {
         bmean = mean(x[x <= 1])
         bvar = var(x[x <= 1])
@@ -393,8 +393,10 @@ lbetagpdcon <- function(x, bshape1 = 1, bshape2 = 1, u = qbeta(0.9, bshape1, bsh
 # (wrapper for likelihood, inputs and checks designed for optimisation)
 nlbetagpdcon <- function(pvector, x, phiu = TRUE, finitelik = FALSE) {
 
+  np = 4 # maximum number of parameters
+
   # Check properties of inputs
-  check.nparam(pvector, nparam = 4)
+  check.nparam(pvector, nparam = np)
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
   check.phiu(phiu, allowfalse = TRUE)
   check.logic(logicarg = finitelik)
@@ -423,9 +425,10 @@ nlbetagpdcon <- function(pvector, x, phiu = TRUE, finitelik = FALSE) {
 proflubetagpdcon <- function(u, pvector, x, phiu = TRUE, method = "BFGS",
   control = list(maxit = 10000), finitelik = FALSE, ...) {
 
+  np = 4 # maximum number of parameters
+  
   # Check properties of inputs
-  np = 3
-  check.nparam(pvector, nparam = np, allownull = TRUE)
+  check.nparam(pvector, nparam = np - 1, allownull = TRUE)
   check.param(u) # do not check probability in likelihood
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
   check.phiu(phiu, allowfalse = TRUE)
@@ -488,8 +491,10 @@ proflubetagpdcon <- function(u, pvector, x, phiu = TRUE, method = "BFGS",
 # (wrapper for likelihood, designed for threshold to be fixed and other parameters optimised)
 nlubetagpdcon <- function(pvector, u, x, phiu = TRUE, finitelik = FALSE) {
 
+  np = 4 # maximum number of parameters
+
   # Check properties of inputs
-  check.nparam(pvector, nparam = 3)
+  check.nparam(pvector, nparam = np - 1)
   check.param(u) # do not check probability in likelihood
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
   check.phiu(phiu, allowfalse = TRUE)
