@@ -27,7 +27,7 @@
 #' vector if initial values are provided, making the full parameter vector 
 #' The full parameter vector is
 #' (\code{lambda}, \code{ul}, \code{xil}, \code{ur}, \code{xir})
-#' if threshold is also estimated and
+#' if thresholds are also estimated and
 #' (\code{lambda}, \code{xil}, \code{xir})
 #' for profile likelihood or fixed threshold approach.
 #' 
@@ -72,7 +72,7 @@
 #' 
 #' @return Log-likelihood is given by \code{\link[evmix:fgkgcon]{lgkgcon}} and it's
 #'   wrappers for negative log-likelihood from \code{\link[evmix:fgkgcon]{nlgkgcon}}
-#'   and \code{\link[evmix:fgkgcon]{nlugkgcon}}. Profile likelihood for single pair of upper and lower
+#'   and \code{\link[evmix:fgkgcon]{nlugkgcon}}. Profile likelihood for both
 #'   thresholds given by \code{\link[evmix:fgkgcon]{proflugkgcon}}. Fitting function
 #'   \code{\link[evmix:fgkgcon]{fgkgcon}} returns a simple list with the
 #'   following elements
@@ -81,8 +81,9 @@
 #'  \code{call}:      \tab \code{optim} call\cr
 #'  \code{x}:         \tab data vector \code{x}\cr
 #'  \code{init}:      \tab \code{pvector}\cr
-#'  \code{fixedu}:    \tab fixed threshold, logical\cr
-#'  \code{useq}:      \tab threshold vector for profile likelihood or scalar for fixed threshold\cr
+#'  \code{fixedu}:    \tab fixed thresholds, logical\cr
+#'  \code{ulseq}:     \tab lower threshold vector for profile likelihood or scalar for fixed threshold\cr
+#'  \code{urseq}:     \tab upper threshold vector for profile likelihood or scalar for fixed threshold\cr
 #'  \code{optim}:     \tab complete \code{optim} output\cr
 #'  \code{mle}:       \tab vector of MLE of parameters\cr
 #'  \code{cov}:       \tab variance-covariance matrix of MLE of parameters\cr
@@ -240,6 +241,7 @@ fgkgcon <- function(x, phiul = TRUE, phiur = TRUE, ulseq = NULL, urseq = NULL, f
 
   check.quant(x)
   n = length(x)
+  np = 5 # maximum number of parameters
 
   if (add.jitter) x = jitter(x, factor, amount)
 
@@ -256,8 +258,8 @@ fgkgcon <- function(x, phiul = TRUE, phiur = TRUE, ulseq = NULL, urseq = NULL, f
   # Check if profile likelihood or fixed threshold is being used
   # and determine initial values for parameters in each case
   if (is.null(ulseq) | is.null(ulseq)) { # not profile or fixed
-    profu = FALSE
-    check.nparam(pvector, nparam = 5, allownull = TRUE)
+
+    check.nparam(pvector, nparam = np, allownull = TRUE)
     
     if (is.null(pvector)) {
       if (n == 1) {
@@ -275,9 +277,8 @@ fgkgcon <- function(x, phiul = TRUE, phiur = TRUE, ulseq = NULL, urseq = NULL, f
     }
     
   } else { # profile or fixed
-    profu = TRUE
     
-    check.nparam(pvector, nparam = 3, allownull = TRUE)
+    check.nparam(pvector, nparam = np - 2, allownull = TRUE)
 
     # profile likelihood for threshold or scalar given
     if ((length(ulseq) != 1) | (length(urseq) != 1)) {
@@ -305,7 +306,7 @@ fgkgcon <- function(x, phiul = TRUE, phiur = TRUE, ulseq = NULL, urseq = NULL, f
       ur = urseq
     }
 
-    if (fixedu) { # threshold fixed (4 parameters)
+    if (fixedu) { # threshold fixed
       if (is.null(pvector)) {
         if (n == 1) {
           stop("Automated bandwidth estimation requires 2 or more kernel centres")
@@ -548,8 +549,10 @@ lgkgcon <- function(x, lambda = NULL, ul = 0, xil = 0, phiul = TRUE,
 # (wrapper for likelihood, inputs and checks designed for optimisation)
 nlgkgcon <- function(pvector, x, phiul = TRUE, phiur = TRUE, kernel = "gaussian", finitelik = FALSE) {
 
+  np = 5 # maximum number of parameters
+
   # Check properties of inputs
-  check.nparam(pvector, nparam = 5)
+  check.nparam(pvector, nparam = np)
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
   check.phiu(phiul, allowfalse = TRUE)
   check.phiu(phiur, allowfalse = TRUE)
@@ -585,9 +588,10 @@ nlgkgcon <- function(pvector, x, phiul = TRUE, phiur = TRUE, kernel = "gaussian"
 proflugkgcon <- function(ulr, pvector, x, phiul = TRUE, phiur = TRUE, kernel = "gaussian",
   method = "BFGS", control = list(maxit = 10000), finitelik = FALSE, ...) {
 
+  np = 5 # maximum number of parameters
+
   # Check properties of inputs
-  np = 3
-  check.nparam(pvector, nparam = np, allownull = TRUE)
+  check.nparam(pvector, nparam = np - 2, allownull = TRUE)
   check.param(ulr, allowvec = TRUE)
   check.nparam(ulr, nparam = 2)
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
@@ -661,8 +665,10 @@ proflugkgcon <- function(ulr, pvector, x, phiul = TRUE, phiur = TRUE, kernel = "
 # cross-validation for KDE component
 nlugkgcon <- function(pvector, ul, ur, x, phiul = TRUE, phiur = TRUE, kernel = "gaussian", finitelik = FALSE) {
 
+  np = 5 # maximum number of parameters
+
   # Check properties of inputs
-  check.nparam(pvector, nparam = 3)
+  check.nparam(pvector, nparam = np - 2)
   check.param(ul)
   check.param(ur)
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
