@@ -39,7 +39,7 @@
 #' 
 #' The full parameter vector is
 #' (\code{nmean}, \code{nsd}, \code{ul}, \code{sigmaul}, \code{xil}, \code{ur}, \code{sigmaur}, \code{xir})
-#' if threshold is also estimated and
+#' if thresholds are also estimated and
 #' (\code{nmean}, \code{nsd}, \code{sigmaul}, \code{xil}, \code{sigmaur}, \code{xir})
 #' for profile likelihood or fixed threshold approach.
 #' 
@@ -68,8 +68,8 @@
 #' 
 #' @return Log-likelihood is given by \code{\link[evmix:fgng]{lgng}} and it's
 #'   wrappers for negative log-likelihood from \code{\link[evmix:fgng]{nlgng}}
-#'   and \code{\link[evmix:fgng]{nlugng}}. Profile likelihood for single
-#'   threshold given by \code{\link[evmix:fgng]{proflugng}}. Fitting function
+#'   and \code{\link[evmix:fgng]{nlugng}}. Profile likelihood for both
+#'   thresholds given by \code{\link[evmix:fgng]{proflugng}}. Fitting function
 #'   \code{\link[evmix:fgng]{fgng}} returns a simple list with the
 #'   following elements
 #'
@@ -77,8 +77,9 @@
 #'  \code{call}:      \tab \code{optim} call\cr
 #'  \code{x}:         \tab data vector \code{x}\cr
 #'  \code{init}:      \tab \code{pvector}\cr
-#'  \code{fixedu}:    \tab fixed threshold, logical\cr
-#'  \code{useq}:      \tab threshold vector for profile likelihood or scalar for fixed threshold\cr
+#'  \code{fixedu}:    \tab fixed thresholds, logical\cr
+#'  \code{ulseq}:     \tab lower threshold vector for profile likelihood or scalar for fixed threshold\cr
+#'  \code{urseq}:     \tab upper threshold vector for profile likelihood or scalar for fixed threshold\cr
 #'  \code{optim}:     \tab complete \code{optim} output\cr
 #'  \code{mle}:       \tab vector of MLE of parameters\cr
 #'  \code{cov}:       \tab variance-covariance matrix of MLE of parameters\cr
@@ -212,6 +213,7 @@ fgng <- function(x, phiul = TRUE, phiur = TRUE, ulseq = NULL, urseq = NULL, fixe
 
   check.quant(x)
   n = length(x)
+  np = 8 # maximum number of parameters
 
   if ((method == "L-BFGS-B") | (method == "BFGS")) finitelik = TRUE
   
@@ -222,8 +224,8 @@ fgng <- function(x, phiul = TRUE, phiur = TRUE, ulseq = NULL, urseq = NULL, fixe
   # Check if profile likelihood or fixed threshold is being used
   # and determine initial values for parameters in each case
   if (is.null(ulseq) | is.null(ulseq)) { # not profile or fixed
-    profu = FALSE
-    check.nparam(pvector, nparam = 8, allownull = TRUE)
+
+    check.nparam(pvector, nparam = np, allownull = TRUE)
     
     if (is.null(pvector)) {
       pvector[1] = mean(x, trim = 0.2)
@@ -239,9 +241,8 @@ fgng <- function(x, phiul = TRUE, phiur = TRUE, ulseq = NULL, urseq = NULL, fixe
     }
     
   } else { # profile or fixed
-    profu = TRUE
     
-    check.nparam(pvector, nparam = 6, allownull = TRUE)
+    check.nparam(pvector, nparam = np - 2, allownull = TRUE)
 
     # profile likelihood for threshold or scalar given
     if ((length(ulseq) != 1) | (length(urseq) != 1)) {
@@ -268,7 +269,7 @@ fgng <- function(x, phiul = TRUE, phiur = TRUE, ulseq = NULL, urseq = NULL, fixe
       ur = urseq
     }
 
-    if (fixedu) { # threshold fixed (4 parameters)
+    if (fixedu) { # threshold fixed
       if (is.null(pvector)) {
         pvector[1] = mean(x, trim = 0.2)
         pvector[2] = sd(x)
@@ -482,8 +483,10 @@ lgng <- function(x, nmean = 0, nsd = 1,
 # (wrapper for likelihood, inputs and checks designed for optimisation)
 nlgng <- function(pvector, x, phiul = TRUE, phiur = TRUE, finitelik = FALSE) {
 
+  np = 8 # maximum number of parameters
+
   # Check properties of inputs
-  check.nparam(pvector, nparam = 8)
+  check.nparam(pvector, nparam = np)
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
   check.phiu(phiul, allowfalse = TRUE)
   check.phiu(phiur, allowfalse = TRUE)
@@ -517,9 +520,10 @@ nlgng <- function(pvector, x, phiul = TRUE, phiur = TRUE, finitelik = FALSE) {
 proflugng <- function(ulr, pvector, x, phiul = TRUE, phiur = TRUE,
   method = "BFGS", control = list(maxit = 10000), finitelik = FALSE, ...) {
 
+  np = 8 # maximum number of parameters
+
   # Check properties of inputs
-  np = 6
-  check.nparam(pvector, nparam = np, allownull = TRUE)
+  check.nparam(pvector, nparam = np - 2, allownull = TRUE)
   check.param(ulr, allowvec = TRUE)
   check.nparam(ulr, nparam = 2)
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
@@ -583,8 +587,10 @@ proflugng <- function(ulr, pvector, x, phiul = TRUE, phiur = TRUE,
 # (wrapper for likelihood, designed for threshold to be fixed and other parameters optimised)
 nlugng <- function(pvector, ul, ur, x, phiul = TRUE, phiur = TRUE, finitelik = FALSE) {
 
+  np = 8 # maximum number of parameters
+
   # Check properties of inputs
-  check.nparam(pvector, nparam = 6)
+  check.nparam(pvector, nparam = np - 2)
   check.param(ul)
   check.param(ur)
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
