@@ -159,6 +159,7 @@ flognormgpdcon <- function(x, phiu = TRUE, useq = NULL, fixedu = FALSE, pvector
 
   check.quant(x)
   n = length(x)
+  np = 4 # maximum number of parameters
 
   if ((method == "L-BFGS-B") | (method == "BFGS")) finitelik = TRUE
   
@@ -169,8 +170,8 @@ flognormgpdcon <- function(x, phiu = TRUE, useq = NULL, fixedu = FALSE, pvector
   # Check if profile likelihood or fixed threshold is being used
   # and determine initial values for parameters in each case
   if (is.null(useq)) { # not profile or fixed
-    profu = FALSE
-    check.nparam(pvector, nparam = 4, allownull = TRUE)
+
+    check.nparam(pvector, nparam = np, allownull = TRUE)
     
     if (is.null(pvector)) {
       pvector[1] = mean(log(x))
@@ -181,9 +182,8 @@ flognormgpdcon <- function(x, phiu = TRUE, useq = NULL, fixedu = FALSE, pvector
     }
     
   } else { # profile or fixed
-    profu = TRUE
     
-    check.nparam(pvector, nparam = 3, allownull = TRUE)
+    check.nparam(pvector, nparam = np - 1, allownull = TRUE)
 
     # profile likelihood for threshold or scalar given
     if (length(useq) != 1) {
@@ -202,7 +202,7 @@ flognormgpdcon <- function(x, phiu = TRUE, useq = NULL, fixedu = FALSE, pvector
       u = useq
     }
 
-    if (fixedu) { # threshold fixed (4 parameters)
+    if (fixedu) { # threshold fixed
       if (is.null(pvector)) {
         pvector[1] = mean(log(x))
         pvector[2] = sd(log(x))
@@ -381,8 +381,10 @@ llognormgpdcon <- function(x, lnmean = 0, lnsd = 1, u = qlnorm(0.9, lnmean, lnsd
 # (wrapper for likelihood, inputs and checks designed for optimisation)
 nllognormgpdcon <- function(pvector, x, phiu = TRUE, finitelik = FALSE) {
 
+  np = 4 # maximum number of parameters
+
   # Check properties of inputs
-  check.nparam(pvector, nparam = 4)
+  check.nparam(pvector, nparam = np)
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
   check.phiu(phiu, allowfalse = TRUE)
   check.logic(logicarg = finitelik)
@@ -411,9 +413,10 @@ nllognormgpdcon <- function(pvector, x, phiu = TRUE, finitelik = FALSE) {
 proflulognormgpdcon <- function(u, pvector, x, phiu = TRUE, method = "BFGS",
   control = list(maxit = 10000), finitelik = FALSE, ...) {
 
+  np = 4 # maximum number of parameters
+
   # Check properties of inputs
-  np = 3
-  check.nparam(pvector, nparam = np, allownull = TRUE)
+  check.nparam(pvector, nparam = np - 1, allownull = TRUE)
   check.param(u) # do not check positivity in likelihood
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
   check.phiu(phiu, allowfalse = TRUE)
@@ -472,8 +475,10 @@ proflulognormgpdcon <- function(u, pvector, x, phiu = TRUE, method = "BFGS",
 # (wrapper for likelihood, designed for threshold to be fixed and other parameters optimised)
 nlulognormgpdcon <- function(pvector, u, x, phiu = TRUE, finitelik = FALSE) {
 
+  np = 4 # maximum number of parameters
+
   # Check properties of inputs
-  check.nparam(pvector, nparam = 3)
+  check.nparam(pvector, nparam = np - 1)
   check.param(u) # do not check positivity in likelihood
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
   check.phiu(phiu, allowfalse = TRUE)
