@@ -248,6 +248,7 @@ fmgammagpdcon <- function(x, M, phiu = TRUE, useq = NULL, fixedu = FALSE, pvecto
 
   check.quant(x)
   n = length(x)
+  np = 3*M + 2 # maximum number of parameters
 
   if (is.unsorted(x)) x = sort(x)
 
@@ -267,8 +268,8 @@ fmgammagpdcon <- function(x, M, phiu = TRUE, useq = NULL, fixedu = FALSE, pvecto
   # Check if profile likelihood or fixed threshold is being used
   # and determine initial values for parameters in each case
   if (is.null(useq)) { # not profile or fixed
-    profu = FALSE
-    check.nparam(pvector, nparam = 3*M + 1, allownull = TRUE)
+
+    check.nparam(pvector, nparam = np - 1, allownull = TRUE)
     
     if (is.null(pvector)) {
       # split dataset into components
@@ -295,9 +296,8 @@ fmgammagpdcon <- function(x, M, phiu = TRUE, useq = NULL, fixedu = FALSE, pvecto
     }
     
   } else { # profile or fixed
-    profu = TRUE
     
-    check.nparam(pvector, nparam = 3*M, allownull = TRUE)
+    check.nparam(pvector, nparam = np - 2, allownull = TRUE)
 
     # profile likelihood for threshold or scalar given
     if (length(useq) != 1) {
@@ -316,7 +316,7 @@ fmgammagpdcon <- function(x, M, phiu = TRUE, useq = NULL, fixedu = FALSE, pvecto
       u = useq
     }
 
-    if (fixedu) { # threshold fixed (4 parameters)
+    if (fixedu) { # threshold fixed
       if (is.null(pvector)) {
         # split dataset into components
         nM = rmultinom(1, n, rep(1/M, M))
@@ -720,9 +720,11 @@ lmgammagpdcon <- function(x, mgshape, mgscale, mgweight, u, xi, phiu = TRUE, log
 # (wrapper for likelihood, inputs and checks designed for optimisation)
 nlmgammagpdcon <- function(pvector, x, M, phiu = TRUE, finitelik = FALSE) {
 
+  np = 3*M + 2 # maximum number of parameters
+
   # Check properties of inputs
   check.param(pvector, allowvec = TRUE)
-  check.nparam(pvector, nparam = 3*M + 1)
+  check.nparam(pvector, nparam = np - 1)
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
   check.phiu(phiu, allowfalse = TRUE)
   check.logic(logicarg = finitelik)
@@ -752,9 +754,11 @@ nlmgammagpdcon <- function(pvector, x, M, phiu = TRUE, finitelik = FALSE) {
 # (wrapper for likelihood, designed for threshold to be fixed and other parameters optimised)
 nlumgammagpdcon <- function(pvector, u, x, M, phiu = TRUE, finitelik = FALSE) {
 
+  np = 3*M + 2 # maximum number of parameters
+
   # Check properties of inputs
   check.param(pvector, allowvec = TRUE)
-  check.nparam(pvector, nparam = 3*M)
+  check.nparam(pvector, nparam = np - 2)
   check.posparam(u)
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
   check.phiu(phiu, allowfalse = TRUE)
@@ -784,9 +788,11 @@ nlumgammagpdcon <- function(pvector, u, x, M, phiu = TRUE, finitelik = FALSE) {
 # with component probabilities separated for EM algorithm
 nlEMmgammagpdcon <- function(pvector, tau, mgweight, x, M, phiu = TRUE, finitelik = FALSE) {
 
+  np.noweight = 2*M + 2 # maximum number of parameters
+
   # Check properties of inputs
   check.param(pvector, allowvec = TRUE)
-  check.nparam(pvector, nparam = 2 * M + 2)
+  check.nparam(pvector, nparam = np.noweight)
   check.nparam(mgweight, nparam = M)
   check.prob(mgweight)
   
@@ -869,10 +875,11 @@ nlEMmgammagpdcon <- function(pvector, tau, mgweight, x, M, phiu = TRUE, finiteli
 proflumgammagpdcon <- function(u, pvector, x, M, phiu = TRUE,
   method = "BFGS", control = list(maxit = 10000), finitelik = FALSE, ...) {
 
+  np = 3*M + 2 # maximum number of parameters
+
   # Check properties of inputs
   check.param(pvector, allowvec = TRUE)
-  np = 3*M
-  check.nparam(pvector, nparam = np, allownull = TRUE)
+  check.nparam(pvector, nparam = np - 2, allownull = TRUE)
   check.posparam(param = u)
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
   check.phiu(phiu, allowfalse = TRUE)
@@ -1050,9 +1057,11 @@ proflumgammagpdcon <- function(u, pvector, x, M, phiu = TRUE,
 # (wrapper for likelihood, designed for threshold to be fixed and other parameters optimised)
 nluEMmgammagpdcon <- function(pvector, u, tau, mgweight, x, M, phiu = TRUE, finitelik = FALSE) {
 
+  np.noweight = 2*M + 2 # maximum number of parameters
+
   # Check properties of inputs
   check.param(pvector, allowvec = TRUE)
-  check.nparam(pvector, nparam = 2*M + 1)
+  check.nparam(pvector, nparam = np.noweight - 1)
   check.posparam(u)
   check.nparam(mgweight, nparam = M)
   check.prob(mgweight)
