@@ -151,6 +151,7 @@ fnormgpdcon <- function(x, phiu = TRUE, useq = NULL, fixedu = FALSE, pvector = N
 
   check.quant(x)
   n = length(x)
+  np = 4 # maximum number of parameters
 
   if ((method == "L-BFGS-B") | (method == "BFGS")) finitelik = TRUE
   
@@ -161,8 +162,8 @@ fnormgpdcon <- function(x, phiu = TRUE, useq = NULL, fixedu = FALSE, pvector = N
   # Check if profile likelihood or fixed threshold is being used
   # and determine initial values for parameters in each case
   if (is.null(useq)) { # not profile or fixed
-    profu = FALSE
-    check.nparam(pvector, nparam = 4, allownull = TRUE)
+
+    check.nparam(pvector, nparam = np, allownull = TRUE)
     
     if (is.null(pvector)) {
       pvector[1] = mean(x, trim = 0.2)
@@ -173,9 +174,8 @@ fnormgpdcon <- function(x, phiu = TRUE, useq = NULL, fixedu = FALSE, pvector = N
     }
     
   } else { # profile or fixed
-    profu = TRUE
     
-    check.nparam(pvector, nparam = 3, allownull = TRUE)
+    check.nparam(pvector, nparam = np - 1, allownull = TRUE)
 
     # profile likelihood for threshold or scalar given
     if (length(useq) != 1) {
@@ -194,7 +194,7 @@ fnormgpdcon <- function(x, phiu = TRUE, useq = NULL, fixedu = FALSE, pvector = N
       u = useq
     }
 
-    if (fixedu) { # threshold fixed (3 parameters)
+    if (fixedu) { # threshold fixed
       if (is.null(pvector)) {
         pvector[1] = mean(x, trim = 0.2)
         pvector[2] = sd(x)
@@ -365,8 +365,10 @@ lnormgpdcon <- function(x, nmean = 0, nsd = 1, u = qnorm(0.9, nmean, nsd),
 # (wrapper for likelihood, inputs and checks designed for optimisation)
 nlnormgpdcon <- function(pvector, x, phiu = TRUE, finitelik = FALSE) {
 
+  np = 4 # maximum number of parameters
+
   # Check properties of inputs
-  check.nparam(pvector, nparam = 4)
+  check.nparam(pvector, nparam = np)
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
   check.phiu(phiu, allowfalse = TRUE)
   check.logic(logicarg = finitelik)
@@ -395,9 +397,10 @@ nlnormgpdcon <- function(pvector, x, phiu = TRUE, finitelik = FALSE) {
 proflunormgpdcon <- function(u, pvector, x, phiu = TRUE, method = "BFGS",
   control = list(maxit = 10000), finitelik = FALSE, ...) {
 
+  np = 4 # maximum number of parameters
+
   # Check properties of inputs
-  np = 3
-  check.nparam(pvector, nparam = np, allownull = TRUE)
+  check.nparam(pvector, nparam = np - 1, allownull = TRUE)
   check.param(u)
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
   check.phiu(phiu, allowfalse = TRUE)
@@ -444,8 +447,10 @@ proflunormgpdcon <- function(u, pvector, x, phiu = TRUE, method = "BFGS",
 # (wrapper for likelihood, designed for threshold to be fixed and other parameters optimised)
 nlunormgpdcon <- function(pvector, u, x, phiu = TRUE, finitelik = FALSE) {
 
+  np = 4 # maximum number of parameters
+
   # Check properties of inputs
-  check.nparam(pvector, nparam = 3)
+  check.nparam(pvector, nparam = np - 1)
   check.param(u)
   check.quant(x, allowmiss = TRUE, allowinf = TRUE)
   check.phiu(phiu, allowfalse = TRUE)
